const mongoose = require('mongoose')

const libs = `${process.cwd()}/libs`;
const config = require(`${libs}/config`);
const log = require(`${libs}/log`)(module);

const locations = require(`${libs}/models/locations`);

const Schema = mongoose.Schema;

// Should define this somewhere else
const MAX_SIMULATION_TIME = 10;


let SimulationSchema = new Schema({
    name: {
        type: String,
        required: true,
    },
    location: Object,
    time: Number,
    failure_rate: Array,
    goals_care: Array,
    goals_inclusion: Array,
});

SimulationSchema.methods.setTime = (t) => {
    t = parseInt(t, 10);
    if(!t || t>MAX_SIMULATION_TIME){
        // Throw an error?
        return;
    }
    this.time = t;
};
SimulationSchema.methods.setLocation = (l) => {
    // Should sanitize
    if(!(l instanceof locations.location)){
        // Throw an error?
        return;
    }
    this.location = l;
};
SimulationSchema.methods.setCareGoals = (g) => {
    // Should sanitize
    this.goals.care = g;
};
SimulationSchema.methods.setInclusionGoals = (g) => {
    // Should sanitize
    this.goals.inclusion = g;
};
SimulationSchema.methods.run = () => {
    /* Runs the Simulation with given parameters */
    // if (!this.name || !this.location || !this.time) {
    //     console.log('This is supposed to be an error.');
    // }
    // identify of location type can be tested with instanceof operator.
    // Example: if (this.location instanceof locations.city) *Do some stuff*
};

module.exports = mongoose.model('Simulation', SimulationSchema);
